==> mvpframework-1.0.5-sources.jar: com/humandevice/android/mvpframework/PresenterDialogFragment.java <==
package com.humandevice.android.mvpframework;

import android.app.Activity;
import android.app.Dialog;
import android.app.DialogFragment;
import android.content.Context;
import android.os.Bundle;
import android.support.annotation.NonNull;
import android.support.annotation.Nullable;
import android.view.View;

import com.humandevice.android.core.layers.LayerView;

/**
 * @date 18.02.2016
 */
public abstract class PresenterDialogFragment<V extends LayerView, P extends Presenter<V>> extends DialogFragment {
    private PresenterCache mPresenterCache;
    private PresenterDelegate<V, P> mPresenterDelegate = new PresenterDelegate<>();

    @SuppressWarnings("deprecation")
    @Override
    public final void onAttach(Activity activity) {
        super.onAttach(activity);
        checkActivityClass(activity);
        onAttachToFragment(activity);
    }

    @Override
    public final void onAttach(Context context) {
        super.onAttach(context);
        checkActivityClass(context);
        onAttachToFragment(context);
    }

    /**
     * @param context context of activity that attached fragment
     */
    public void onAttachToFragment(Context context) {
    }

    @Override
    public void onCreate(@Nullable Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        mPresenterDelegate.onCreate(mPresenterCache, savedInstanceState, getPresenterClass());
    }

    @Override
    public void onViewCreated(View view, @Nullable Bundle savedInstanceState) {
        super.onViewCreated(view, savedInstanceState);
        initView(view);
    }

    @Override
    public Dialog onCreateDialog(Bundle savedInstanceState) {
        Dialog dialog = createDialog(savedInstanceState);
        //noinspection unchecked
        mPresenterDelegate.onViewCreated((V) this);
        return dialog;
    }

    @Override
    public void onResume() {
        super.onResume();
        mPresenterDelegate.onResume();
    }

    @Override
    public void onPause() {
        super.onPause();
        mPresenterDelegate.onPause();
    }

    @Override
    public void onSaveInstanceState(@NonNull Bundle outState) {
        super.onSaveInstanceState(outState);
        mPresenterDelegate.onSaveInstanceState(outState);
    }

    @Override
    public void onDestroyView() {
        super.onDestroyView();
        mPresenterDelegate.onDestroyView();
    }

    @Override
    public void onDestroy() {
        super.onDestroy();
        mPresenterDelegate.onDestroy(mPresenterCache);
    }

    private void checkActivityClass(Context context) {
        if (context instanceof PresenterCache) {
            mPresenterCache = (PresenterCache) context;
        } else {
            throw new RuntimeException(getClass().getSimpleName() + " must be attached to an Activity that implements "
                    + PresenterCache.class.getSimpleName());
        }
    }


    public P getPresenter() {
        return mPresenterDelegate.getPresenter();
    }

    /**
     * Get Class of the presenter implementation
     */
    public abstract Class<? extends P> getPresenterClass();

    protected abstract Dialog createDialog(Bundle savedInstanceState);

    /**
     * Find all views in root view
     */
    protected abstract void initView(View view);
}

==> mvpframework-1.1.0-sources.jar: com/humandevice/android/mvpframework/PresenterDialogFragment.java <==
package com.humandevice.android.mvpframework;

import android.app.Activity;
import android.app.Dialog;
import android.app.DialogFragment;
import android.content.Context;
import android.os.Bundle;
import android.support.annotation.NonNull;
import android.support.annotation.Nullable;
import android.view.View;

/**
 * @date 18.02.2016
 */
public abstract class PresenterDialogFragment<V extends LayerView, P extends Presenter<V>> extends DialogFragment {
    private PresenterCache presenterCache;
    private PresenterDelegate<V, P> presenterDelegate = new PresenterDelegate<>();

    @SuppressWarnings("deprecation")
    @Override
    public final void onAttach(Activity activity) {
        super.onAttach(activity);
        checkActivityClass(activity);
        onAttachToFragment(activity);
    }

    @Override
    public final void onAttach(Context context) {
        super.onAttach(context);
        checkActivityClass(context);
        onAttachToFragment(context);
    }

    /**
     * @param context context of activity that attached fragment
     */
    public void onAttachToFragment(Context context) {
    }

    @Override
    public void onCreate(@Nullable Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        presenterDelegate.onCreate(presenterCache, savedInstanceState, getPresenterClass());
    }

    @Override
    public void onViewCreated(View view, @Nullable Bundle savedInstanceState) {
        super.onViewCreated(view, savedInstanceState);
        initView(view);
    }

    @Override
    public Dialog onCreateDialog(Bundle savedInstanceState) {
        Dialog dialog = createDialog(savedInstanceState);
        //noinspection unchecked
        presenterDelegate.onViewCreated((V) this);
        return dialog;
    }

    @Override
    public void onResume() {
        super.onResume();
        presenterDelegate.onResume();
    }

    @Override
    public void onPause() {
        super.onPause();
        presenterDelegate.onPause();
    }

    @Override
    public void onSaveInstanceState(@NonNull Bundle outState) {
        super.onSaveInstanceState(outState);
        presenterDelegate.onSaveInstanceState(outState);
    }

    @Override
    public void onDestroyView() {
        super.onDestroyView();
        presenterDelegate.onDestroyView();
    }

    @Override
    public void onDestroy() {
        super.onDestroy();
        presenterDelegate.onDestroy(presenterCache);
    }

    private void checkActivityClass(Context context) {
        if (context instanceof PresenterCache) {
            presenterCache = (PresenterCache) context;
        } else {
            throw new RuntimeException(getClass().getSimpleName() + " must be attached to an Activity that implements "
                    + PresenterCache.class.getSimpleName());
        }
    }


    public P getPresenter() {
        return presenterDelegate.getPresenter();
    }

    /**
     * Get Class of the presenter implementation
     */
    public abstract Class<? extends P> getPresenterClass();

    protected abstract Dialog createDialog(Bundle savedInstanceState);

    /**
     * Find all views in root view
     */
    protected abstract void initView(View view);
}
